#include <QApplication>
#include <QUndoCommand>
#include <QUndoView>
#include <QShortcut>
#include <QStyle>
#include <QDebug>

struct Command : public QUndoCommand
{
    Command(const QString &text) : QUndoCommand(text)  {}

    void undo() { qDebug() << "undo " + text(); }

    void redo() { qDebug() << "redo " + text(); }
};

class UndoView : public QUndoView {
    Q_OBJECT
public:
    explicit UndoView(QUndoStack *stack, QWidget *parent = 0) : QUndoView(stack, parent) {}

public slots:
    void dumpSelection()
    { qDebug() << selectionMode() << selectionModel()->selectedIndexes(); }
};

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);

    QUndoStack stack;
    stack.push(new Command("command 1"));
    stack.push(new Command("command 2"));
    stack.push(new Command("command 3"));

    QString t =  QT_VERSION_STR;
#if QT_VERSION >= 0x050000
    t += ' ' + app.platformName();
#endif
    t += ' ' + app.style()->objectName();
    qDebug() << t;

    UndoView view(&stack);
    view.setWindowTitle(t);
    new QShortcut(Qt::CTRL + Qt::Key_D, &view, SLOT(dumpSelection()));
    view.show();

    return app.exec();
}

#include "main.moc"
